Crate crit

Crate crit 

crit provides predicates for conveniently managing multiple cross target builds.

Structs

Crit
Crit models a multiplatform build operation.
Target
Target identifies computing platforms.

Enums

CritError
CritError models bad computer states.

Statics

ARTIFACT_ROOT_PATH
ARTIFACT_ROOT_PATH denotes the path housing crit internal files.
BUILD_MODES
BUILD_MODES enumerates cargo’s major build modes.
CONFIGURATION_FILENAME
CONFIGURATION_FILENAME denotes the file path to an optional TOML configuration file, relative to the current working directory.
CRIT_ARTIFACT_ROOT
CRIT_ARTIFACT_ROOT denotes the directory housing crit internal files.
CROSS_DIR_PATHBUF
CROSS_DIR_PATHBUF denotes the pathbuf housing cross internal files.
DEFAULT_BINARY_EXTENSIONS
DEFAULT_BINARY_EXTENSIONS collects common cargo build binary file extensions.
RUST_TARGET_PATTERN

Functions

clean
clean removes:
clean_artifact_root
clean_artifact_root removes CRIT_ARTIFACT_ROOT directory.
clean_containers
clean_containers removes leftover cross Docker containers.
get_applications
get_applications queries Cargo.toml for the list of binary application names.