crit provides predicates for conveniently managing multiple cross target builds.
Structs
Enums
- Crit
Error - CritError models bad computer states.
Statics
- ARTIFACT_
ROOT_ PATH - ARTIFACT_ROOT_PATH denotes the path housing crit internal files.
- BUILD_
MODES - BUILD_MODES enumerates cargo’s major build modes.
- CONFIGURATION_
FILENAME - CONFIGURATION_FILENAME denotes the file path to an optional TOML configuration file, relative to the current working directory.
- CRIT_
ARTIFACT_ ROOT - CRIT_ARTIFACT_ROOT denotes the directory housing crit internal files.
- CROSS_
DIR_ PATHBUF - CROSS_DIR_PATHBUF denotes the pathbuf housing cross internal files.
- DEFAULT_
BINARY_ EXTENSIONS - DEFAULT_BINARY_EXTENSIONS collects common cargo build binary file extensions.
- RUST_
TARGET_ PATTERN
Functions
- clean
- clean removes:
- clean_
artifact_ root - clean_artifact_root removes CRIT_ARTIFACT_ROOT directory.
- clean_
containers - clean_containers removes leftover cross Docker containers.
- get_
applications - get_applications queries Cargo.toml for the list of binary application names.